.onAttach <- function(lib, pkg) {
    packageStartupMessage("EBS v2.8 Loaded \n")
   
    
}


